==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidTerminalAllReqBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取当前有效终端信息
 * @author: 777771
 * @date: 2021-58-04 22:58:50
 */
public class TerminalGetValidTerminalAllReqBean {
    /**
     * 终端编码
     */
    private String terminalCode;

    /**
     * 终端名称
     */
    private String terminalName;

    /**
     * 终端渠道编码
     */
    private String channelCode;

    /**
     * 终端渠道名称
     */
    private String channelName;

    /**
     * 终端类型编码
     */
    private String terminalTypeCode;

    /**
     * 终端类型名称
     */
    private String terminalTypeName;

    /**
     * 当前页
     */
    private Long page;

    /**
     * 每月条数
     */
    private Long pageSize;

    /**
     * 总页数
     */
    private Long totalPage;

    /**
     * 总条数
     */
    private Long total;

    public TerminalGetValidTerminalAllReqBean(){
    }

    public TerminalGetValidTerminalAllReqBean(String terminalCode,String terminalName,String channelCode,String channelName,String terminalTypeCode,String terminalTypeName,Long page,Long pageSize,Long totalPage,Long total){
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
        this.channelCode=channelCode;
        this.channelName=channelName;
        this.terminalTypeCode=terminalTypeCode;
        this.terminalTypeName=terminalTypeName;
        this.page=page;
        this.pageSize=pageSize;
        this.totalPage=totalPage;
        this.total=total;
    }

    private String getTerminalCode() {
        return terminalCode;
    }

    private void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    private String getTerminalName() {
        return terminalName;
    }

    private void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
    private String getChannelCode() {
        return channelCode;
    }

    private void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }
    private String getChannelName() {
        return channelName;
    }

    private void setChannelName(String channelName) {
        this.channelName = channelName;
    }
    private String getTerminalTypeCode() {
        return terminalTypeCode;
    }

    private void setTerminalTypeCode(String terminalTypeCode) {
        this.terminalTypeCode = terminalTypeCode;
    }
    private String getTerminalTypeName() {
        return terminalTypeName;
    }

    private void setTerminalTypeName(String terminalTypeName) {
        this.terminalTypeName = terminalTypeName;
    }
    private Long getPage() {
        return page;
    }

    private void setPage(Long page) {
        this.page = page;
    }
    private Long getPageSize() {
        return pageSize;
    }

    private void setPageSize(Long pageSize) {
        this.pageSize = pageSize;
    }
    private Long getTotalPage() {
        return totalPage;
    }

    private void setTotalPage(Long totalPage) {
        this.totalPage = totalPage;
    }
    private Long getTotal() {
        return total;
    }

    private void setTotal(Long total) {
        this.total = total;
    }
}

==> biostime-openapi-sdk-1.5.9.1-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidTerminalAllReqBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取当前有效终端信息
 * @author: 13258
 * @date: 2021-46-10 13:46:41
 */
public class TerminalGetValidTerminalAllReqBean {
    /**
     * 终端编码
     */
    private String terminalCode;

    /**
     * 终端名称
     */
    private String terminalName;

    /**
     * 终端渠道编码
     */
    private String channelCode;

    /**
     * 终端渠道名称
     */
    private String channelName;

    /**
     * 终端类型编码
     */
    private String terminalTypeCode;

    /**
     * 终端类型名称
     */
    private String terminalTypeName;

    /**
     * 当前页
     */
    private Long page;

    /**
     * 每月条数
     */
    private Long pageSize;

    /**
     * 总页数
     */
    private Long totalPage;

    /**
     * 总条数
     */
    private Long total;

    public TerminalGetValidTerminalAllReqBean(){
    }

    public TerminalGetValidTerminalAllReqBean(String terminalCode,String terminalName,String channelCode,String channelName,String terminalTypeCode,String terminalTypeName,Long page,Long pageSize,Long totalPage,Long total){
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
        this.channelCode=channelCode;
        this.channelName=channelName;
        this.terminalTypeCode=terminalTypeCode;
        this.terminalTypeName=terminalTypeName;
        this.page=page;
        this.pageSize=pageSize;
        this.totalPage=totalPage;
        this.total=total;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    public String getTerminalName() {
        return terminalName;
    }

    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }
    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }
    public String getTerminalTypeCode() {
        return terminalTypeCode;
    }

    public void setTerminalTypeCode(String terminalTypeCode) {
        this.terminalTypeCode = terminalTypeCode;
    }
    public String getTerminalTypeName() {
        return terminalTypeName;
    }

    public void setTerminalTypeName(String terminalTypeName) {
        this.terminalTypeName = terminalTypeName;
    }
    public Long getPage() {
        return page;
    }

    public void setPage(Long page) {
        this.page = page;
    }
    public Long getPageSize() {
        return pageSize;
    }

    public void setPageSize(Long pageSize) {
        this.pageSize = pageSize;
    }
    public Long getTotalPage() {
        return totalPage;
    }

    public void setTotalPage(Long totalPage) {
        this.totalPage = totalPage;
    }
    public Long getTotal() {
        return total;
    }

    public void setTotal(Long total) {
        this.total = total;
    }
}
